@@ -88,6 +88,7 @@ class CommandMeta(type, meta):
         parent: Optional[Group] = MISSING,
         guild_only: bool = MISSING,
         default_permissions: Optional[Permissions] = MISSING,
+        nsfw: bool = False,
     ) -> Union[_Command, ContextMenu]:
         if not bases or bases == (Command, Generic):  # This metaclass should only operate on subclasses
             return super().__new__(cls, classname, bases, attrs)
@@ -169,6 +170,7 @@ class CommandMeta(type, meta):
                 callback=_generate_callback(sub, fake=True),  # type: ignore # The cls type is correct
                 parent=parent or None,
                 guild_ids=guild_ids,
+                nsfw=nsfw,
             )
         else:
             if description or parent:
@@ -177,6 +179,7 @@ class CommandMeta(type, meta):
                 name=name if name is not MISSING else classname,
                 callback=_generate_callback(sub),  # type: ignore # The cls type is correct
                 guild_ids=guild_ids,
+                nsfw=nsfw,
             )
 
         _inject_class_based_information(sub, command)
@@ -226,10 +229,17 @@ class Command(metaclass=CommandMeta):
         Defaults to ``False``.
 
         Due to a Discord limitation, this does not work on subcommands.
-    parent: :class:`Group`
+    parent: :class:`~discord.app_commands.Group`
         The command's parent.
 
         Due to a Discord limitation, context menu commands cannot have parents.
+    nsfw: :class:`bool`
+        Whether the command is NSFW and should only work in NSFW channels. Defaults to ``False``.
+
+        Due to a Discord limitation, this does not work on subcommands.
+
+        .. versionadded:: 1.1
+
 
     Attributes
     -----------
@@ -244,7 +254,7 @@ class Command(metaclass=CommandMeta):
 
         This method is called when the command is used.
 
-        All the parameters and :attr:`interaction` will be available at this point.
+        All the parameters and :attr:`.interaction` will be available at this point.
         """
         pass
 
@@ -256,7 +266,7 @@ class Command(metaclass=CommandMeta):
         If it returns a ``False``\-like value then during invocation a
         :exc:`~discord.app_commands.CheckFailure` exception is raised and sent to the appropriate error handlers.
 
-        :attr:`interaction` will be available at this point.
+        :attr:`.interaction` will be available at this point.
         """
         return True
 
@@ -268,7 +278,7 @@ class Command(metaclass=CommandMeta):
         By default this prints to :data:`sys.stderr` however it could be
         overridden to have a different implementation.
 
-        :attr:`interaction` will be available at this point.
+        :attr:`.interaction` will be available at this point.
 
         Parameters
         -----------
@@ -405,9 +415,9 @@ class Command(metaclass=CommandMeta):
 
         Raises
         -------
-        HTTPException
+        ~discord.HTTPException
             Deferring the interaction failed.
-        InteractionResponded
+        ~discord.InteractionResponded
             This interaction has already been responded to before.
         """
         await self.interaction.response.defer(ephemeral=ephemeral)
@@ -451,7 +461,7 @@ class SlashCommand(Command, Generic[CommandT]):
         Defaults to ``False``.
 
         Due to a Discord limitation, this does not work on subcommands.
-    parent: :class:`Group`
+    parent: :class:`~discord.app_commands.Group`
         The command's parent.
 
     """
@@ -463,7 +473,7 @@ class SlashCommand(Command, Generic[CommandT]):
 
         This method is called when an autocomplete interaction is triggered.
 
-        Some of the parameters, :attr:`interaction`, and :attr:`id` will be available at this point.
+        Some of the parameters and :attr:`.interaction` will be available at this point.
 
         .. note::
 
